# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.4.4] - 2026-03-23

- Fix packages path

## [0.4.3] - 2026-03-23

- Fix suggestions path

## [0.4.2] - 2026-03-22

- Fix packaging

## [0.4.1] - 2026-03-22

- Better structure for Python files

## [0.4.0] - 2026-03-22

- Remove --ci option
- Improve formatting of listed packages

## [0.3.0] - 2026-03-17

- Add --format and --ci options to scan command

## [0.2.0] - 2026-03-17

- Initial CLI published on pypi.org

## [0.1.0] - 2026-02-26

- Initial website and dataset
